==> cgal_4.11.orig.tar.xz: CGAL-4.11/examples/Periodic_2_triangulation_2/p2t2_info_insert_with_pair_iterator_2.cpp <==
#include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
#include <CGAL/Periodic_2_Delaunay_triangulation_2.h>
#include <CGAL/Periodic_2_triangulation_traits_2.h>
#include <CGAL/Triangulation_vertex_base_with_info_2.h>
#include <vector>

typedef CGAL::Exact_predicates_inexact_constructions_kernel         K;
typedef CGAL::Periodic_2_triangulation_traits_2<K>                  Gt;
typedef CGAL::Triangulation_vertex_base_with_info_2<unsigned, Gt>   Vb;
typedef CGAL::Periodic_2_triangulation_face_base_2<Gt>              Fb;
typedef CGAL::Triangulation_data_structure_2<Vb, Fb>                 Tds;
typedef CGAL::Periodic_2_Delaunay_triangulation_2<Gt, Tds>          Delaunay;
typedef Delaunay::Point                                             Point;

int main()
{
  std::vector< std::pair<Point, unsigned> > points;
  points.push_back( std::make_pair(Point(0.0, 0.0), 0) );
  points.push_back( std::make_pair(Point(0.1, 0.0), 1) );
  points.push_back( std::make_pair(Point(0.0, 0.1), 2) );
  points.push_back( std::make_pair(Point(0.1, 0.4), 3) );
  points.push_back( std::make_pair(Point(0.2, 0.2), 4) );
  points.push_back( std::make_pair(Point(0.4, 0.0), 5) );

  Delaunay T;
  T.insert( points.begin(), points.end() );

  CGAL_assertion( T.number_of_vertices() == 6 );

  // check that the info was correctly set.
  Delaunay::Finite_vertices_iterator vit;
  for (vit = T.finite_vertices_begin(); vit != T.finite_vertices_end(); ++vit)
    if( points[ vit->info() ].first != vit->point() )
      {
        std::cerr << "Error different info" << std::endl;
        exit(EXIT_FAILURE);
      }
  std::cout << "OK" << std::endl;

  return 0;
}

==> cgal_4.13.orig.tar.xz: CGAL-4.13/examples/Periodic_2_triangulation_2/p2t2_info_insert_with_pair_iterator_2.cpp <==
#include <CGAL/Exact_predicates_inexact_constructions_kernel.h>

#include <CGAL/Periodic_2_Delaunay_triangulation_2.h>
#include <CGAL/Periodic_2_Delaunay_triangulation_traits_2.h>
#include <CGAL/Triangulation_vertex_base_with_info_2.h>

#include <iostream>
#include <vector>

typedef CGAL::Exact_predicates_inexact_constructions_kernel         K;
typedef CGAL::Periodic_2_Delaunay_triangulation_traits_2<K>         Gt;
typedef CGAL::Triangulation_vertex_base_with_info_2<unsigned, Gt>   Vb;
typedef CGAL::Periodic_2_triangulation_face_base_2<Gt>              Fb;
typedef CGAL::Triangulation_data_structure_2<Vb, Fb>                Tds;
typedef CGAL::Periodic_2_Delaunay_triangulation_2<Gt, Tds>          Delaunay;
typedef Delaunay::Point                                             Point;

int main()
{
  std::vector< std::pair<Point, unsigned> > points;
  points.push_back( std::make_pair(Point(0.0, 0.0), 0) );
  points.push_back( std::make_pair(Point(0.1, 0.0), 1) );
  points.push_back( std::make_pair(Point(0.0, 0.1), 2) );
  points.push_back( std::make_pair(Point(0.1, 0.4), 3) );
  points.push_back( std::make_pair(Point(0.2, 0.2), 4) );
  points.push_back( std::make_pair(Point(0.4, 0.0), 5) );

  Delaunay T;
  T.insert( points.begin(), points.end() );

  CGAL_assertion( T.number_of_vertices() == 6 );

  // check that the info was correctly set.
  Delaunay::Finite_vertices_iterator vit;
  for (vit = T.finite_vertices_begin(); vit != T.finite_vertices_end(); ++vit)
  {
    if( points[ vit->info() ].first != vit->point() )
    {
      std::cerr << "Error different info" << std::endl;
      exit(EXIT_FAILURE);
    }
  }
  std::cout << "OK" << std::endl;

  return 0;
}
